/***************************************************************************
 *   Copyright (C) 2004 by Stephan Mres                                   *
 *   Erdling@gmx.net                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/
#ifndef CSNIPPET_H
#define CSNIPPET_H

#include <tqobject.h>
#include <tqlistview.h>
#include <tdeaction.h>
#include <tqsignalmapper.h>

/**
@author Stephan Mres
*/

class CSnippet : public TQObject {
  TQ_OBJECT
  
public:
  CSnippet(TQString sKey, TQString sValue, TQListViewItem *lvi, TQObject *parent = 0, const char *name = 0);
  ~CSnippet();
  TQString getKey() 						{ return _sKey; }
  TQString getValue()						{ return _sValue; }
  TQListViewItem* getListViewItem() const	{ return _lvi; }
  void setKey(const TQString& sKey) 				{ _sKey = sKey; }
  void setValue(const TQString& sValue) 			{ _sValue = sValue; }

protected:
  TQString            _sKey;
  TQString            _sValue;
  TQListViewItem      *_lvi;
};

#endif
